==> unit-1.3.8-sources.jar: io/intino/goros/unit/box/rest/resources/PostAddDatastoreCubeFactResource.java <==
package io.intino.goros.unit.box.rest.resources;

import java.util.List;
import java.util.ArrayList;
import io.intino.alexandria.exceptions.*;
import io.intino.goros.unit.box.*;
import io.intino.alexandria.core.Box;
import io.intino.alexandria.rest.*;
import io.intino.alexandria.http.spark.SparkManager;
import io.intino.alexandria.http.spark.SparkPushService;

import io.intino.goros.unit.box.schemas.*;

public class PostAddDatastoreCubeFactResource implements Resource {

	private UnitBox box;
	private SparkManager<SparkPushService> manager;

	public PostAddDatastoreCubeFactResource(UnitBox box, SparkManager manager) {
		this.box = box;
		this.manager = manager;
	}

	public void execute() throws AlexandriaException {
		write(fill(new io.intino.goros.unit.box.actions.PostAddDatastoreCubeFactAction()).execute());
	}

	private io.intino.goros.unit.box.actions.PostAddDatastoreCubeFactAction fill(io.intino.goros.unit.box.actions.PostAddDatastoreCubeFactAction action) throws AlexandriaException {
		action.box = this.box;
		action.context = context();
		try {
			action.name = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("name"), String.class);
			action.cube = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("cube"), String.class);
			action.data = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("data"), String.class);
		} catch (Throwable e) {
			action.onMalformedRequest(e);
		}
		return action;
	}

	private void write(String object) {
		manager.write(io.intino.alexandria.rest.ResponseAdapter.adapt(object));
	}

	private io.intino.alexandria.http.spark.SparkContext context() {
		io.intino.alexandria.http.spark.SparkContext context = new io.intino.alexandria.http.spark.SparkContext(manager);

		context.put("ip", manager.ip());
		return context;
	}
}

==> unit-2.1.7-sources.jar: io/intino/goros/unit/box/rest/resources/PostAddDatastoreCubeFactResource.java <==
package io.intino.goros.unit.box.rest.resources;

import java.util.List;
import java.util.Set;
import java.util.ArrayList;
import io.intino.alexandria.exceptions.*;
import io.intino.goros.unit.box.*;
import io.intino.alexandria.core.Box;
import io.intino.alexandria.rest.*;
import io.intino.alexandria.http.server.AlexandriaHttpManager;
import io.intino.alexandria.http.pushservice.PushService;

import io.intino.goros.unit.box.schemas.*;

public class PostAddDatastoreCubeFactResource implements Resource {

	private UnitBox box;
	private AlexandriaHttpManager<PushService<?,?>> manager;

	public PostAddDatastoreCubeFactResource(UnitBox box, AlexandriaHttpManager manager) {
		this.box = box;
		this.manager = manager;
	}

	public void execute() throws AlexandriaException {
		write(fill(new io.intino.goros.unit.box.actions.PostAddDatastoreCubeFactAction()).execute());
	}

	private io.intino.goros.unit.box.actions.PostAddDatastoreCubeFactAction fill(io.intino.goros.unit.box.actions.PostAddDatastoreCubeFactAction action) throws AlexandriaException {
		action.box = this.box;
		action.context = context();
		try {
			action.name = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("name"), String.class);
			action.cube = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("cube"), String.class);
			action.data = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("data"), String.class);
		} catch (Throwable e) {
			action.onMalformedRequest(e);
		}
		return action;
	}

	private void write(String object) {
		manager.write(io.intino.alexandria.rest.ResponseAdapter.adapt(object));
	}

	private io.intino.alexandria.http.server.AlexandriaHttpContext context() {
		io.intino.alexandria.http.server.AlexandriaHttpContext context = new io.intino.alexandria.http.server.AlexandriaHttpContext(manager);

		context.put("pathInfo", manager.request().raw().getPathInfo());
		context.put("ip", manager.ip());
		return context;
	}
}
